@@ -4,9 +4,11 @@ import collections
 import lxml.etree as ET
 from slugify import slugify
 
-from freud_api_crawler.xml import XMLReader
+from acdh_xml_pyutils.xml import XMLReader
 from freud_api_crawler.freud_api_crawler import TEI_DUMMY
 
+# ToDO: Check if this code is still needed
+
 
 def make_div_list(glob_pattern):
     """defaultdict of tei:divs fetched from XML/TEI matching the past in glob pattern
@@ -24,6 +26,7 @@ def make_div_list(glob_pattern):
             ".//tei:title[@type='manifestation']/text()", namespaces=doc.nsmap
         )[0]
         pub_id = f'{doc.tree.xpath(".//tei:rs[1]/@ref", namespaces=doc.nsmap)[0]}'
+        man_id = f'{doc.tree.xpath(".//@xml:id", namespaces=doc.nsmap)[0]}'
         pub_title = doc.tree.xpath(".//tei:rs[1]/text()", namespaces=doc.nsmap)[0]
         work_title = doc.tree.xpath(".//tei:title[@type='work']/tei:rs/text()", namespaces=doc.nsmap)[0]
         work_id = doc.tree.xpath(".//tei:title[@type='work']/tei:rs/@ref", namespaces=doc.nsmap)[0]
@@ -36,7 +39,8 @@ def make_div_list(glob_pattern):
                 "first_page": first_page,
                 "div": div,
                 "work_title": work_title,
-                "work_id": work_id
+                "work_id": work_id,
+                "man_id": man_id
             }
             divs.append(item)
 
@@ -51,7 +55,7 @@ def create_united_files(glob_pattern):
     output_dir = glob_pattern.replace("*.xml", 'merged')
     try:
         os.makedirs(output_dir)
-    except Exception as e:
+    except Exception as e:  # noqa: F841
         pass
     d = make_div_list(glob_pattern)
     xml_obj = XMLReader(TEI_DUMMY)
@@ -61,11 +65,12 @@ def create_united_files(glob_pattern):
         doc = ET.parse(TEI_DUMMY)
         save_path = os.path.join(output_dir, f"{slug_name}.xml")
         root_el = doc.xpath('//tei:TEI', namespaces=xml_obj.nsmap)[0]
-        root_el.attrib["{http://www.w3.org/XML/1998/namespace}base"] = f"https://whatever.com"
+        root_el.attrib["{http://www.w3.org/XML/1998/namespace}base"] = "https://whatever.com"
         root_el.attrib[
             "{http://www.w3.org/XML/1998/namespace}id"
-        ] = f"manifestation__{pub_id}"
+        ] = f"{value[0]['man_id']}"
         t_p = doc.xpath('//tei:title[@type="publication"]', namespaces=xml_obj.nsmap)[0]
+        t_p.attrib['ref'] = f"#bibl__{pub_id}"
         t_p.text = f"{value[0]['pub_title']}"
         work_t_p = doc.xpath('//tei:title[@type="work"]', namespaces=xml_obj.nsmap)[0]
         work_t_p.text = f"{value[0]['work_title']}"
